@@ -118,7 +118,7 @@ class BaseAutoML(BaseEstimator, ABC):
         }
 
     def _check_can_load(self):
-        """ Checks if AutoML can be loaded from a folder"""
+        """Checks if AutoML can be loaded from a folder"""
         if self.results_path is not None:
             # Dir exists and can be loaded
             if os.path.exists(self.results_path) and os.path.exists(
@@ -952,7 +952,7 @@ class BaseAutoML(BaseEstimator, ABC):
             if self._stack_models:
                 self.verbose_print("AutoML will stack models")
             if self._train_ensemble:
-                self.verbose_print("AutoML will ensemble availabe models")
+                self.verbose_print("AutoML will ensemble available models")
 
             self._start_time = time.time()
             if self._time_ctrl is not None:
@@ -1119,7 +1119,7 @@ class BaseAutoML(BaseEstimator, ABC):
         return self
 
     def _update_errors_report(self, model_name, error_msg):
-        """Append error message to errors.md file. """
+        """Append error message to errors.md file."""
         errors_filename = os.path.join(self._get_results_path(), "errors.md")
         with open(errors_filename, "a") as fout:
             self.verbose_print(f"There was an error during {model_name} training.")
@@ -1344,12 +1344,12 @@ class BaseAutoML(BaseEstimator, ABC):
         )
 
     def _get_mode(self):
-        """ Gets the current mode"""
+        """Gets the current mode"""
         self._validate_mode()
         return deepcopy(self.mode)
 
     def _get_ml_task(self):
-        """ Gets the current ml_task. If "auto" it is determined"""
+        """Gets the current ml_task. If "auto" it is determined"""
         self._validate_ml_task()
         if self.ml_task == "auto":
             classes_number = self.n_classes
@@ -1366,7 +1366,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.ml_task)
 
     def _get_results_path(self):
-        """ Gets the current results_path"""
+        """Gets the current results_path"""
         # if we already have the results path set, please return it
         if self._results_path is not None:
             return self._results_path
@@ -1406,7 +1406,7 @@ class BaseAutoML(BaseEstimator, ABC):
         raise AutoMLException("Cannot set directory for AutoML results")
 
     def _get_total_time_limit(self):
-        """ Gets the current total_time_limit"""
+        """Gets the current total_time_limit"""
         self._validate_total_time_limit()
         if self._get_mode() == "Optuna":
             return None  # there no training limit for model in the Optuna mode
@@ -1414,12 +1414,12 @@ class BaseAutoML(BaseEstimator, ABC):
         return deepcopy(self.total_time_limit)
 
     def _get_model_time_limit(self):
-        """ Gets the current model_time_limit"""
+        """Gets the current model_time_limit"""
         self._validate_model_time_limit()
         return deepcopy(self.model_time_limit)
 
     def _get_algorithms(self):
-        """ Gets the current algorithms. If "auto" it is determined"""
+        """Gets the current algorithms. If "auto" it is determined"""
         self._validate_algorithms()
         if self.algorithms == "auto":
             if self._get_mode() == "Explain":
@@ -1465,12 +1465,12 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.algorithms)
 
     def _get_train_ensemble(self):
-        """ Gets the current train_ensemble"""
+        """Gets the current train_ensemble"""
         self._validate_train_ensemble()
         return deepcopy(self.train_ensemble)
 
     def _get_stack_models(self):
-        """ Gets the current stack_models"""
+        """Gets the current stack_models"""
         self._validate_stack_models()
         if self.stack_models == "auto":
             val = self._get_validation_strategy()
@@ -1481,7 +1481,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.stack_models)
 
     def _get_eval_metric(self):
-        """ Gets the current eval_metric"""
+        """Gets the current eval_metric"""
         self._validate_eval_metric()
         if isinstance(self.eval_metric, types.FunctionType):
             UserDefinedEvalMetric().set_metric(self.eval_metric)
@@ -1498,7 +1498,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.eval_metric)
 
     def _get_validation_strategy(self):
-        """ Gets the current validation_strategy"""
+        """Gets the current validation_strategy"""
         strat = {}
         self._validate_validation_strategy()
         if self.validation_strategy == "auto":
@@ -1542,7 +1542,7 @@ class BaseAutoML(BaseEstimator, ABC):
         return deepcopy(self.verbose)
 
     def _get_explain_level(self):
-        """ Gets the current explain_level"""
+        """Gets the current explain_level"""
         self._validate_explain_level()
         if self.explain_level == "auto":
             if self._get_mode() == "Explain":
@@ -1571,7 +1571,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.golden_features)
 
     def _get_features_selection(self):
-        """ Gets the current features_selection"""
+        """Gets the current features_selection"""
         self._validate_features_selection()
         if self.features_selection == "auto":
             if self._get_mode() == "Explain":
@@ -1586,7 +1586,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.features_selection)
 
     def _get_start_random_models(self):
-        """ Gets the current start_random_models"""
+        """Gets the current start_random_models"""
         self._validate_start_random_models()
         if self.start_random_models == "auto":
             if self._get_mode() == "Explain":
@@ -1601,7 +1601,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.start_random_models)
 
     def _get_hill_climbing_steps(self):
-        """ Gets the current hill_climbing_steps"""
+        """Gets the current hill_climbing_steps"""
         self._validate_hill_climbing_steps()
         if self.hill_climbing_steps == "auto":
             if self._get_mode() == "Explain":
@@ -1616,7 +1616,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.hill_climbing_steps)
 
     def _get_top_models_to_improve(self):
-        """ Gets the current top_models_to_improve"""
+        """Gets the current top_models_to_improve"""
         self._validate_top_models_to_improve()
         if self.top_models_to_improve == "auto":
             if self._get_mode() == "Explain":
@@ -1631,7 +1631,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.top_models_to_improve)
 
     def _get_boost_on_errors(self):
-        """ Gets the current boost_on_errors"""
+        """Gets the current boost_on_errors"""
         self._validate_boost_on_errors()
         if self.boost_on_errors == "auto":
             val = self._get_validation_strategy()
@@ -1649,7 +1649,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.boost_on_errors)
 
     def _get_kmeans_features(self):
-        """ Gets the current kmeans_features"""
+        """Gets the current kmeans_features"""
         self._validate_kmeans_features()
         if self.kmeans_features == "auto":
             if self._get_mode() == "Explain":
@@ -1664,7 +1664,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.kmeans_features)
 
     def _get_mix_encoding(self):
-        """ Gets the current mix_encoding"""
+        """Gets the current mix_encoding"""
         self._validate_mix_encoding()
         if self.mix_encoding == "auto":
             if self._get_mode() == "Explain":
@@ -1679,7 +1679,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.mix_encoding)
 
     def _get_max_single_prediction_time(self):
-        """ Gets the current max_single_prediction_time"""
+        """Gets the current max_single_prediction_time"""
         self._validate_max_single_prediction_time()
         if self.max_single_prediction_time is None:
             if self._get_mode() == "Perform":
@@ -1689,7 +1689,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.max_single_prediction_time)
 
     def _get_optuna_time_budget(self):
-        """ Gets the current optuna_time_budget"""
+        """Gets the current optuna_time_budget"""
         self._validate_optuna_time_budget()
 
         if self.optuna_time_budget is None:
@@ -1703,7 +1703,7 @@ class BaseAutoML(BaseEstimator, ABC):
             return deepcopy(self.optuna_time_budget)
 
     def _get_optuna_init_params(self):
-        """ Gets the current optuna_init_params"""
+        """Gets the current optuna_init_params"""
         self._validate_optuna_init_params()
         if self._get_mode() != "Optuna":
             # use only for mode Optuna
@@ -1711,7 +1711,7 @@ class BaseAutoML(BaseEstimator, ABC):
         return deepcopy(self.optuna_init_params)
 
     def _get_optuna_verbose(self):
-        """ Gets the current optuna_verbose"""
+        """Gets the current optuna_verbose"""
         self._validate_optuna_verbose()
         # use only for mode Optuna
         if self._get_mode() != "Optuna":
@@ -1719,17 +1719,17 @@ class BaseAutoML(BaseEstimator, ABC):
         return deepcopy(self.optuna_verbose)
 
     def _get_n_jobs(self):
-        """ Gets the current n_jobs"""
+        """Gets the current n_jobs"""
         self._validate_n_jobs()
         return deepcopy(self.n_jobs)
 
     def _get_random_state(self):
-        """ Gets the current random_state"""
+        """Gets the current random_state"""
         self._validate_random_state()
         return deepcopy(self.random_state)
 
     def _validate_mode(self):
-        """ Validates mode parameter"""
+        """Validates mode parameter"""
         valid_modes = ["Explain", "Perform", "Compete", "Optuna"]
         if self.mode not in valid_modes:
             raise ValueError(
@@ -1737,7 +1737,7 @@ class BaseAutoML(BaseEstimator, ABC):
             )
 
     def _validate_ml_task(self):
-        """ Validates ml_task parameter"""
+        """Validates ml_task parameter"""
         if isinstance(self.ml_task, str) and self.ml_task == "auto":
             return
 
@@ -1747,7 +1747,7 @@ class BaseAutoML(BaseEstimator, ABC):
             )
 
     def _validate_results_path(self):
-        """ Validates path parameter"""
+        """Validates path parameter"""
         if self.results_path is None or isinstance(self.results_path, str):
             return
 
@@ -1756,19 +1756,19 @@ class BaseAutoML(BaseEstimator, ABC):
         )
 
     def _validate_total_time_limit(self):
-        """ Validates total_time_limit parameter"""
+        """Validates total_time_limit parameter"""
         if self.total_time_limit is None:
             return
         if self.total_time_limit is not None:
             check_greater_than_zero_integer(self.total_time_limit, "total_time_limit")
 
     def _validate_model_time_limit(self):
-        """ Validates model_time_limit parameter"""
+        """Validates model_time_limit parameter"""
         if self.model_time_limit is not None:
             check_greater_than_zero_integer(self.model_time_limit, "model_time_limit")
 
     def _validate_algorithms(self):
-        """ Validates algorithms parameter"""
+        """Validates algorithms parameter"""
         if isinstance(self.algorithms, str) and self.algorithms == "auto":
             return
 
@@ -1779,12 +1779,12 @@ class BaseAutoML(BaseEstimator, ABC):
                 )
 
     def _validate_train_ensemble(self):
-        """ Validates train_ensemble parameter"""
+        """Validates train_ensemble parameter"""
         # `train_ensemble` defaults to True, no further checking required
         check_bool(self.train_ensemble, "train_ensemble")
 
     def _validate_stack_models(self):
-        """ Validates stack_models parameter"""
+        """Validates stack_models parameter"""
         # `stack_models` defaults to "auto". If "auto" return, else check if is valid bool
         if isinstance(self.stack_models, str) and self.stack_models == "auto":
             return
@@ -1792,7 +1792,7 @@ class BaseAutoML(BaseEstimator, ABC):
         check_bool(self.stack_models, "stack_models")
 
     def _validate_eval_metric(self):
-        """ Validates eval_metric parameter"""
+        """Validates eval_metric parameter"""
         if isinstance(self.eval_metric, types.FunctionType):
             return
 
@@ -1834,7 +1834,7 @@ class BaseAutoML(BaseEstimator, ABC):
             )
 
     def _validate_validation_strategy(self):
-        """ Validates validation parameter"""
+        """Validates validation parameter"""
         if (
             isinstance(self.validation_strategy, str)
             and self.validation_strategy == "auto"
@@ -1853,11 +1853,11 @@ class BaseAutoML(BaseEstimator, ABC):
             raise ValueError(f"Expected dict with keys: {' , '.join(required_keys)}")
 
     def _validate_verbose(self):
-        """ Validates verbose parameter"""
+        """Validates verbose parameter"""
         check_positive_integer(self.verbose, "verbose")
 
     def _validate_explain_level(self):
-        """ Validates explain_level parameter"""
+        """Validates explain_level parameter"""
         if isinstance(self.explain_level, str) and self.explain_level == "auto":
             return
         valid_explain_levels = [0, 1, 2]
@@ -1871,7 +1871,7 @@ class BaseAutoML(BaseEstimator, ABC):
             )
 
     def _validate_golden_features(self):
-        """ Validates golden_features parameter"""
+        """Validates golden_features parameter"""
         if isinstance(self.golden_features, str) and self.golden_features == "auto":
             return
         if isinstance(self.golden_features, int):
@@ -1879,7 +1879,7 @@ class BaseAutoML(BaseEstimator, ABC):
         check_bool(self.golden_features, "golden_features")
 
     def _validate_features_selection(self):
-        """ Validates features_selection parameter"""
+        """Validates features_selection parameter"""
         if (
             isinstance(self.features_selection, str)
             and self.features_selection == "auto"
@@ -1888,7 +1888,7 @@ class BaseAutoML(BaseEstimator, ABC):
         check_bool(self.features_selection, "features_selection")
 
     def _validate_start_random_models(self):
-        """ Validates start_random_models parameter"""
+        """Validates start_random_models parameter"""
         if (
             isinstance(self.start_random_models, str)
             and self.start_random_models == "auto"
@@ -1897,7 +1897,7 @@ class BaseAutoML(BaseEstimator, ABC):
         check_greater_than_zero_integer(self.start_random_models, "start_random_models")
 
     def _validate_hill_climbing_steps(self):
-        """ Validates hill_climbing_steps parameter"""
+        """Validates hill_climbing_steps parameter"""
         if (
             isinstance(self.hill_climbing_steps, str)
             and self.hill_climbing_steps == "auto"
@@ -1906,7 +1906,7 @@ class BaseAutoML(BaseEstimator, ABC):
         check_positive_integer(self.hill_climbing_steps, "hill_climbing_steps")
 
     def _validate_top_models_to_improve(self):
-        """ Validates top_models_to_improve parameter"""
+        """Validates top_models_to_improve parameter"""
         if (
             isinstance(self.top_models_to_improve, str)
             and self.top_models_to_improve == "auto"
@@ -1915,25 +1915,25 @@ class BaseAutoML(BaseEstimator, ABC):
         check_positive_integer(self.top_models_to_improve, "top_models_to_improve")
 
     def _validate_boost_on_errors(self):
-        """ Validates boost_on_errors parameter"""
+        """Validates boost_on_errors parameter"""
         if isinstance(self.boost_on_errors, str) and self.boost_on_errors == "auto":
             return
         check_bool(self.boost_on_errors, "boost_on_errors")
 
     def _validate_kmeans_features(self):
-        """ Validates kmeans_features parameter"""
+        """Validates kmeans_features parameter"""
         if isinstance(self.kmeans_features, str) and self.kmeans_features == "auto":
             return
         check_bool(self.kmeans_features, "kmeans_features")
 
     def _validate_mix_encoding(self):
-        """ Validates mix_encoding parameter"""
+        """Validates mix_encoding parameter"""
         if isinstance(self.mix_encoding, str) and self.mix_encoding == "auto":
             return
         check_bool(self.mix_encoding, "mix_encoding")
 
     def _validate_max_single_prediction_time(self):
-        """ Validates max_single_prediction_time parameter"""
+        """Validates max_single_prediction_time parameter"""
         if self.max_single_prediction_time is None:
             return
         check_greater_than_zero_integer_or_float(
@@ -1941,13 +1941,13 @@ class BaseAutoML(BaseEstimator, ABC):
         )
 
     def _validate_optuna_time_budget(self):
-        """ Validates optuna_time_budget parameter"""
+        """Validates optuna_time_budget parameter"""
         if self.optuna_time_budget is None:
             return
         check_greater_than_zero_integer(self.optuna_time_budget, "optuna_time_budget")
 
     def _validate_optuna_init_params(self):
-        """ Validates optuna_init_params parameter"""
+        """Validates optuna_init_params parameter"""
         if self.optuna_init_params is None:
             return
         if type(self.optuna_init_params) is not dict:
@@ -1956,17 +1956,17 @@ class BaseAutoML(BaseEstimator, ABC):
             )
 
     def _validate_optuna_verbose(self):
-        """ Validates optuna_verbose parameter"""
+        """Validates optuna_verbose parameter"""
         if self.optuna_verbose is None:
             return
         check_bool(self.optuna_verbose, "optuna_verbose")
 
     def _validate_n_jobs(self):
-        """ Validates mix_encoding parameter"""
+        """Validates mix_encoding parameter"""
         check_integer(self.n_jobs, "n_jobs")
 
     def _validate_random_state(self):
-        """ Validates random_state parameter"""
+        """Validates random_state parameter"""
         check_positive_integer(self.random_state, "random_state")
 
     def to_json(self):
